@@ -30,18 +30,10 @@ sudo mkdir -p /etc/tempest
 sudo cp $TEMPEST_BASE/etc/tempest.conf.sample /etc/tempest/tempest.conf
 
 # Set test parameters
-sudo sed -i s'/#username = <None>/username = solum_user_a/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#tenant_name = <None>/tenant_name = solum_tenant_a/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#password = <None>/password = solum/'g /etc/tempest/tempest.conf
 sudo sed -i s'/#auth_version = <None>/auth_version = v2/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#admin_domain_name = <None>/admin_domain_name = Default/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#admin_tenant_id = <None>/admin_tenant_id = 22c3991d53eb42cbaff28428b90760c2/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#admin_tenant_name = <None>/admin_tenant_name = admin/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#admin_password = <None>/admin_password = solum/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#admin_username = <None>/admin_username = admin/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#alt_tenant_name = <None>/alt_tenant_name = alt_demo/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#alt_password = <None>/alt_password = solum/'g /etc/tempest/tempest.conf
-sudo sed -i s'/#alt_username = <None>/alt_username = alt_demo/'g /etc/tempest/tempest.conf
+sudo sed -i s'/#admin_project_name = <None>/admin_project_name = service/'g /etc/tempest/tempest.conf
+sudo sed -i s'/#admin_password = <None>/admin_password = secretadmin/'g /etc/tempest/tempest.conf
+sudo sed -i s'/#admin_username = <None>/admin_username = solum/'g /etc/tempest/tempest.conf
 sudo sed -i s'/#uri_v3 = <None>/uri_v3 = http\:\/\/127.0.0.1\:5000\/v3/'g /etc/tempest/tempest.conf
 sudo sed -i s'/#uri = <None>/uri = http\:\/\/127.0.0.1\:5000\/v2.0\//'g /etc/tempest/tempest.conf
 
@@ -59,4 +51,4 @@ sudo sh -c 'echo creating temporary dhcp log file >> /opt/stack/logs/screen-n-dh
 
 
 # Reset the virt driver in nova's /etc/nova/nova.conf
-sudo sed -i s'/compute_driver = novadocker.virt.docker.driver.DockerDriver//'g /etc/nova/nova.conf
\ No newline at end of file
+sudo sed -i s'/compute_driver = novadocker.virt.docker.driver.DockerDriver//'g /etc/nova/nova.conf
