@@ -15,16 +15,18 @@
 import uuid
 
 from oslo_config import cfg
+from oslo_log import log as logging
 from swiftclient import exceptions as swiftexp
 
+from solum.api.handlers import common
 from solum.api.handlers import handler
 from solum.api.handlers import userlog_handler
 from solum.common import exception as exc
+from solum.common import solum_glanceclient
 from solum.common import solum_swiftclient
 from solum import objects
 from solum.objects import image
 from solum.objects.sqlalchemy import app
-from solum.openstack.common import log as logging
 from solum.worker import api
 
 
@@ -35,6 +37,9 @@ API_SERVICE_OPTS = [
     cfg.StrOpt('operator_project_id',
                default='',
                help='Tenant id of the operator account used to create LPs'),
+    cfg.IntOpt('max_languagepack_limit',
+               default=10,
+               help='Maximum number of languagepacks allowed'),
 ]
 
 
@@ -44,6 +49,7 @@ def list_opts():
 
 CONF = cfg.CONF
 CONF.register_opts(API_SERVICE_OPTS, group='api')
+cfg.CONF.import_opt('image_storage', 'solum.worker.config', group='worker')
 
 
 class LanguagePackHandler(handler.Handler):
@@ -73,6 +79,13 @@ class LanguagePackHandler(handler.Handler):
             else:
                 return False
 
+    def _check_if_limit_of_lps_reached(self, ctxt):
+        num_of_lps = objects.registry.Image.get_num_of_lps(ctxt)
+        if num_of_lps >= int(cfg.CONF.api.max_languagepack_limit):
+            msg = "Number of languagepacks reached limit of '%s'." % (
+                cfg.CONF.api.max_languagepack_limit)
+            raise exc.ResourceLimitExceeded(reason=msg)
+
     def get(self, id):
         """Return a languagepack."""
         return objects.registry.Image.get_lp_by_name_or_uuid(
@@ -82,8 +95,13 @@ class LanguagePackHandler(handler.Handler):
         """Return all languagepacks."""
         return objects.registry.Image.get_all_languagepacks(self.context)
 
-    def create(self, data, lp_metadata):
+    def create(self, data, lp_metadata, lp_params):
         """Create a new languagepack."""
+
+        self._check_if_limit_of_lps_reached(self.context)
+
+        common.check_url(data['source_uri'])
+
         try:
             # Check if an LP with the same name exists.
             objects.registry.Image.get_lp_by_name_or_uuid(
@@ -101,7 +119,7 @@ class LanguagePackHandler(handler.Handler):
                 db_obj.tags.append(lp_metadata)
 
             db_obj.create(self.context)
-            self._start_build(db_obj)
+            self._start_build(db_obj, lp_params)
             return db_obj
         else:
             raise exc.ResourceExists(name=data['name'])
@@ -115,16 +133,25 @@ class LanguagePackHandler(handler.Handler):
                 self._check_lp_referenced_in_any_app(self.context, db_obj)):
             raise exc.LPStillReferenced(name=uuid)
 
-        # Delete image file from swift
         if db_obj.docker_image_name:
             img_filename = db_obj.docker_image_name.split('-', 1)[1]
-            try:
-                swift = solum_swiftclient.SwiftClient(self.context)
-                swift.delete_object('solum_lp', img_filename)
-            except swiftexp.ClientException:
-                raise exc.AuthorizationFailure(
-                    client='swift',
-                    message="Unable to delete languagepack image from swift.")
+
+            if cfg.CONF.worker.image_storage == 'swift':
+                # Delete image file from swift
+                try:
+                    swift = solum_swiftclient.SwiftClient(self.context)
+                    swift.delete_object('solum_lp', img_filename)
+                except swiftexp.ClientException:
+                    raise exc.AuthorizationFailure(
+                        client='swift',
+                        message="Unable to delete languagepack image "
+                                "from swift.")
+            elif cfg.CONF.worker.image_storage == 'glance':
+                glance = solum_glanceclient.GlanceClient(self.context)
+                glance.delete_image_by_name(img_filename)
+            else:
+                LOG.error("Unrecognized image_storage option specified.")
+                return
 
         # Delete logs
         log_handler = userlog_handler.UserlogHandler(self.context)
@@ -132,7 +159,7 @@ class LanguagePackHandler(handler.Handler):
 
         return db_obj.destroy(self.context)
 
-    def _start_build(self, image):
+    def _start_build(self, image, lp_params):
         git_info = {
             'source_url': image.source_uri,
         }
@@ -142,4 +169,5 @@ class LanguagePackHandler(handler.Handler):
             name=image.name,
             source_format=image.source_format,
             image_format=image.image_format,
-            artifact_type=image.artifact_type)
+            artifact_type=image.artifact_type,
+            lp_params=lp_params)
