@@ -15,8 +15,7 @@
 import datetime
 
 import mock
-
-from solum.openstack.common import uuidutils
+from oslo_utils import uuidutils
 
 
 fakeAuthTokenHeaders = {'X-User-Id': u'773a902f022949619b5c2f32cd89d419',
@@ -76,8 +75,11 @@ class FakeApp(mock.Mock):
         self.language_pack = 'test_lp'
         self.deleted = False
         self.source = {
-            'repository': 'http://example.git',
+            'repository': 'http://github.com/example/a.git',
             'revision': 'master',
+            'repo_token': 'test-repo-token',
+            'private': False,
+            'private_ssh_key': 'test-private-ssh-key'
         }
         self.ports = [80]
         self.workflow_config = {
@@ -87,6 +89,7 @@ class FakeApp(mock.Mock):
         self.stack_id = ''
         self.trigger_actions = ["unittest", "build", "deploy"]
         self.scale_config = dict()
+        self.raw_content = "{\"repo_token\": \"test-repo-token\"}"
 
     def as_dict(self):
         return {
@@ -101,6 +104,7 @@ class FakeApp(mock.Mock):
             'ports': self.ports,
             'workflow_config': self.workflow_config,
             'stack_id': self.stack_id,
+            'raw_content': self.raw_content
         }
 
 
