@@ -21,7 +21,7 @@ import mock
 from oslo_config import cfg
 
 from solum.common import exception
-from solum.openstack.common.gettextutils import _
+from solum.i18n import _
 from solum.tests import base
 from solum.tests import fakes
 from solum.tests import utils
